<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://fncd.net
 * @since      1.0.0
 *
 * @package    Final_Countdown
 * @subpackage Final_Countdown/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Final_Countdown
 * @subpackage Final_Countdown/admin
 * @author     Final Countdown <fncd@thangbom.us>
 */
class Final_Countdown_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Final_Countdown_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Final_Countdown_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		
		/* load WP colorpicker */
		wp_enqueue_style( 'wp-color-picker' );
		
	
		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/final-countdown-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Final_Countdown_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Final_Countdown_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		add_thickbox();
		
		/* load jQuery-ui slider */
		wp_enqueue_script( 'jquery-ui-slider' );
		
		/* load jQuery-ui datepicker */
		wp_enqueue_script( 'jquery-ui-datepicker' );
		
		/* load WP colorpicker */
		wp_enqueue_script( 'wp-color-picker' );
		
		/* load jQuery UI timepicker addon */
		wp_enqueue_script( 'jquery-ui-timepicker', plugin_dir_url( __FILE__ ) . 'js/jquery-ui-timepicker-addon.min.js', array( 'jquery', 'jquery-ui-slider', 'jquery-ui-datepicker' ) );
		
		//wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/final-countdown-admin.js', array( 'jquery' ), $this->version, false );

	}
	
	/**
	 * Register Countdown Button for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function countdown_button() {
	
		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Final_Countdown_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Final_Countdown_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
	
		$img =  plugin_dir_url( __FILE__ ) . 'images/countdown_logo.png';
		$context="";
		$title = 'Add Final Countdown';	
		$context .= '<a class="button thickbox" title="Create Final Countdown and insert in posts/pages"    href="'.admin_url("admin-ajax.php").'?action=final_countdown_window_manager&height=750&width=640">
		<span class="wp-media-buttons-icon" style="background: url('.$img.'); background-repeat: no-repeat; background-position: left bottom;"></span>
		Add Final Countdown
		</a>';  
		return $context;
	
	}
	
	
	/**
	 * Countdown Button window/popup content for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function final_countdown_window_insert_content() {
	
		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Final_Countdown_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Final_Countdown_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		
		$timezone_identifiers = DateTimeZone::listIdentifiers();
		
	?>
		<style>
	 
		#final_countdown_window_manager > tbody > tr:nth-child(odd) {
		  background-color: rgba(176, 176, 176, 0.07);
		}
		#final_countdown_window_manager>tfoot>tr>td{
			border-top:1px solid #ccc;
		}
		#final_countdown_window_manager>tbody>tr>td:first-child{
			width:30%;
		}
		#TB_window{  
			overflow-y: auto;
		}
		#TB_ajaxContent{
			width:95% !important;
		}
		.wp-picker-holder{
			position: absolute;
			z-index: 100000;
		}
		.desription_class{
			float: right;
			cursor: default;
			color: #0074a2;
			font-size: 18px;
			font-weight: bold;
			border: 1px solid #000000;
			border-radius: 200px;
			height: 20px;
			padding-left: 6px;
			padding-right: 6px;
			margin-left: 15px;
		}
		.final_countdown_spinner{float: left;}	
		</style>
		<table id="final_countdown_window_manager" class="wp-list-table widefat fixed posts section_parametrs_table">  
                <tbody>
               		<tr>
						<td>
							Event Name <span title="This is the name of the Event you are counting down to." class="desription_class">?</span>
						</td>
						<td>
							<input type="text" name="final_countdown_event_name"  id="final_countdown_event_name" value="">
						</td>                
					</tr>
                	<tr>
						<td>
							Date <span title="This is the date of the Event." class="desription_class">?</span>
						</td>
						<td>
							<input type="text" name="final_countdown_date"  id="final_countdown_date" value="" readonly>
						</td>                
					</tr>
                    <tr>
						<td>
							Time <span title="This is the time of the Event." class="desription_class">?</span>
						</td>
						<td>
							<input type="text" name="final_countdown_time"  id="final_countdown_time" value="" readonly>
						</td>                
					</tr>
                    <tr>
						<td>
							Timezone  <span title="This is the timezone of the event." class="desription_class">?</span>
						</td>
						<td>
							<select id="final_countdown_timezone" name="final_countdown_timezone" >
                              <?php 
                              	foreach ($timezone_identifiers as $key=>$value)
                              	{
                              		?>
                              		<option value="<?php echo $value;?>"><?php echo $value;?></option>
                              		<?php 
                              	}
                              ?>
                        	</select>
                         </td>             
					</tr>
					<tr>
						<td>
							Count up <span title="Check this box if you want the Countdown to count up to display the time since the Event expired." class="desription_class">?</span>
						</td>
						<td>
							<input type="checkbox" name="final_countdown_countup"  id="final_countdown_countup" value="true">
						</td>                
					</tr>
					<tr>
						<td>
							Font Style <span title="This is font style of text." class="desription_class">?</span>
						</td>
					 	
                        <td style="vertical-align: top !important;">
                            <div style="margin-right:3px; width:25%;float:left;">
                            	<select id="final_countdown_font" name="final_countdown_font">
	                                <option selected="selected" value="0">Style 1</option>
	                                <option value="1">Style 2</option>
	                                <option value="2">Style 3</option>
	                                <option value="3">Style 4</option>
	                                <option value="4">Style 5</option>
	                                <option value="5">Style 6</option>
	                        	</select>
                            </div>
                           	<div style="width:70%;float:left">
                              <!-- <img alt="" src="<?php echo plugin_dir_url( __FILE__ ) . 'images/Font0.png';?>" style="width:100%;height:auto;" id="final_countdown_font_img"> -->   
                                 <iframe src="//fncd.net/embed?id=wt3jxdI"" style="width:100%;height:150px;" id="final_countdown_preview" ></iframe>
                            </div>
                         </td>       
                                       
					</tr>
					<tr>
						<td>
							Title Color <span title="The color of the Event name text." class="desription_class">?</span>
						</td>
						<td>
							<input type="text" name="final_countdown_title_color"  id="final_countdown_title_color"  value="#ffffff">
						</td>                
					</tr>
					<tr>
						<td>
							Background Color <span title="The color of the Background." class="desription_class">?</span>
						</td>
						<td>
							<input type="text" name="final_countdown_background_color"  id="final_countdown_background_color" value="#000000">
						</td>                
					</tr>
					<tr>
						<td>
							Background Opacity<span title="The Background Color Opacity." class="desription_class">?</span>
						</td>
						<td>
							<input type="hidden" name="final_countdown_background_opacity"  id="final_countdown_background_opacity" value="0" >
							<div class="ui-opacitypicker-div">
								<div id="final_countdown_slider" style="float: left;width: 210px;"></div>
								<div id="final_countdown_slider_val"  style="float: left;margin-left: 10px;"></label>
							</div>
							
						</td>                
					</tr>
					<tr>
						<td>
							Width <span title="Width of Countdown block." class="desription_class">?</span>
						</td>
						<td> 
							<input type="text" name="final_countdown_width"  id="final_countdown_width" value="300px"> (Ex. 100px or 100%)
						</td>                
					</tr>
					<tr>
						<td>
							Height <span title="Height of Countdown block." class="desription_class">?</span>
						</td>
						<td>
							<input type="text" name="final_countdown_height"  id="final_countdown_height" value="150px"> (Ex. 100px or 100%)
						</td>                
					</tr>
                </tbody>
                 <tfoot>
                	<tr>                      
                        <td colspan="2">
                        	 <div style="display:inline-block; float:right;" ><span class="final_countdown_spinner spinner">&nbsp;</span><input type="button" id="insert_final_countdown" name="insert_final_countdown" value="Insert Final Countdown" class="button button-primary" onClick="insert_final_countdown();"/></div>
                        </td>                
                    </tr>
                </tfoot>
            </table>    
            <script>
          
        	jQuery('#final_countdown_window_manager').ready(function(e) {
        		jQuery('#TB_window').css('max-height',(jQuery('#final_countdown_window_manager').height()+100)+'px');
             	jQuery('#TB_ajaxContent').css('max-height',(jQuery('#final_countdown_window_manager').height()+26)+'px');
        		jQuery("#final_countdown_title_color,#final_countdown_background_color").wpColorPicker({defaultColor:'#ffffff',change:function(event, ui){
        			event.preventDefault();
        			generatePreviewString();
            	}});
        		jQuery('#final_countdown_date').datepicker({
        			   showOtherMonths: true,
        		       showButtonPanel: true,
        		       defaultDate:0,
        		       minDate:0,
        		       dateFormat: 'dd/mm/yy',
        		       onSelect: function(dateText) {
        		    	   generatePreviewString();
        		       }
        	      });
        		jQuery("#final_countdown_date").datepicker("setDate", new Date());
        		jQuery('#final_countdown_time').timepicker({
        			onSelect: function(dateText) {
     		    	   generatePreviewString();
     		       }
  		        });
        		jQuery("#final_countdown_time").datepicker("setDate", new Date());


        		/*jQuery('#final_countdown_font').on('change',function(){
					jQuery("#final_countdown_font_img").attr('src',"<?php //echo plugin_dir_url( __FILE__ ) . 'images/';?>"+"Font"+jQuery('#final_countdown_font').val()+".png");
        		});*/


        		jQuery( "#final_countdown_slider" ).slider({
        		      value:1,
        		      min: 0,
        		      max: 1,
        		      step: 0.01,
        		      slide: function( event, ui ) {
        		    	  jQuery( "#final_countdown_background_opacity" ).val(ui.value);
        		    	  jQuery( "#final_countdown_slider_val" ).html (ui.value);
        		    	  generatePreviewString();
        		      }
        		    });
        		jQuery( "#final_countdown_background_opacity" ).val( jQuery( "#final_countdown_slider" ).slider( "value" ) );
        		jQuery( "#final_countdown_slider_val" ).html (jQuery( "#final_countdown_slider" ).slider( "value" ));

        		generatePreviewString();

        		jQuery("#final_countdown_timezone,#final_countdown_font,#final_countdown_countup").on('change',function(){
        			generatePreviewString();
            	})
            	jQuery("#final_countdown_event_name").on('blur',function(){
        			generatePreviewString();
            	})
        	});

        	function generatePreviewString()
        	{
                var tagtext;
				var event_name="";
				var event_date="";
				var event_time="";
				var timezone="";
				var count_up="false";
				var font_style="0";
				var title_color="-1";
				var backgroound_color="-1";
								
				if(jQuery('#final_countdown_event_name').length)
					event_name=jQuery.trim(jQuery('#final_countdown_event_name').val());
					
				if(jQuery('#final_countdown_date').length)
					event_date=jQuery('#final_countdown_date').val();
					
				if(jQuery('#final_countdown_time').length)
					event_time=jQuery('#final_countdown_time').val();
					
				if(jQuery('#final_countdown_timezone').length)
					timezone=jQuery('#final_countdown_timezone').val();
				
				if(jQuery('#final_countdown_countup').length)
					count_up=(jQuery('#final_countdown_countup').val()=="true")?"true":"false";
					
				if(jQuery('#final_countdown_font').length)
					font_style=jQuery('#final_countdown_font').val();
				
				if(jQuery('#final_countdown_title_color').length)
				{
					title_color="ff"+(jQuery('#final_countdown_title_color').val().substr(1));
					title_color=signedIntBin2Dec(hex2bin(title_color.toUpperCase()), 30)+"";
					
				}	
				if(jQuery('#final_countdown_background_color').length)
				{
					
					background_opacity =percentageToHex(jQuery( "#final_countdown_background_opacity" ).val())
					backgroound_color=background_opacity+(jQuery('#final_countdown_background_color').val().substr(1));
					backgroound_color=signedIntBin2Dec(hex2bin(backgroound_color.toUpperCase()), 30)+"";
				}

				if(event_name=="")
				{
					event_name="Event Name";
				}

				
				var event_date_arr=event_date.split("/");
				var event_time_arr=event_time.split(":");
				var target_time=new Date(event_date_arr[2],(event_date_arr[1]-1),event_date_arr[0],event_time_arr[0],event_time_arr[1],0,0).getTime();
				
				var url = "https://fncd.net/embed-preview?name="+event_name+"&targetTime="+target_time+"&timezone="+timezone+"&countUp="+count_up+"&font="+font_style+"&color="+title_color+"&bgColor="+backgroound_color+"&titleColor="+title_color+"&borderColor=-9539986";

				jQuery("#final_countdown_preview").attr("src",url);
				
        	}

        	function hex2bin(hexNumber)
        	{
        		var hexaString = "0123456789ABCDEF";
        		var binaryArray = new Array ("0000","0001","0010","0011","0100","0101","0110","0111","1000","1001","1010","1011","1100","1101","1110","1111");
        		var binaryString;
        		binaryString = "";
        		for (var index = 0; index < hexNumber.length; index++)
        		{
        			binaryString += binaryArray[hexaString.indexOf(hexNumber.charAt(index))];
        		}
        		return binaryString;
        	}

        	function fastBin2Dec(binString)
        	{
        		var decNumber;
        		decNumber = 0;
        		for (var index = 0; index < binString.length; index++)
        		{
        			if (binString.charAt(index) == "1")
        			{
        				decNumber += Math.pow(2,binString.length-index-1);
        			}
        		}
        		return decNumber;
        	}
        	        	
        	function signedIntBin2Dec(expression)
        	{
        		var value;
        		value = fastBin2Dec(expression);
        		value =	integerFitRange(value, 0, 4294967295);
        		if (value > 2147483647)
        		{
        			value -= 4294967296;
        		}
        		return value;
        	}

        	function integerFitRange(value, min, max)
        	{
        		var temp;
        		temp = parseInt(Math.floor(value)+"");
        		if (temp<min)
        		{
        			temp = min;
        		}
        		if (temp>max)
        		{
        			temp = max;
        		}
        		return temp;
        	}

			function percentageToHex(percentage)
			{
				i = percentage;
				var alpha = Math.round(i * 255);
				var hex = alpha.toString(16);
				if (hex.length == 1) hex = "0" + hex;
				return hex;
				
			}
    	     	        	
            function insert_final_countdown() {          

                var tagtext;
				var event_name="";
				var event_date="";
				var event_time="";
				var timezone="";
				var count_up="false";
				var font_style="0";
				var title_color="-1";
				var backgroound_color="-1";
				var width="";
				var height="";
								
				if(jQuery('#final_countdown_event_name').length)
					event_name=jQuery.trim(jQuery('#final_countdown_event_name').val());
					
				if(jQuery('#final_countdown_date').length)
					event_date=jQuery('#final_countdown_date').val();
					
				if(jQuery('#final_countdown_time').length)
					event_time=jQuery('#final_countdown_time').val();
					
				if(jQuery('#final_countdown_timezone').length)
					timezone=jQuery('#final_countdown_timezone').val();
				
				if(jQuery('#final_countdown_countup').length)
					count_up=(jQuery('#final_countdown_countup').val()=="true")?"true":"false";
					
				if(jQuery('#final_countdown_font').length)
					font_style=jQuery('#final_countdown_font').val();
				
				if(jQuery('#final_countdown_title_color').length)
				{
					title_color="ff"+(jQuery('#final_countdown_title_color').val().substr(1));
					title_color=signedIntBin2Dec(hex2bin(title_color.toUpperCase()), 30)+"";
					
				}	
				if(jQuery('#final_countdown_background_color').length)
				{
					
					background_opacity =percentageToHex(jQuery( "#final_countdown_background_opacity" ).val())
					backgroound_color=background_opacity+(jQuery('#final_countdown_background_color').val().substr(1));
					backgroound_color=signedIntBin2Dec(hex2bin(backgroound_color.toUpperCase()), 30)+"";
				}

				if(jQuery('#final_countdown_width').length)
					width=jQuery('#final_countdown_width').val();
					
				if(jQuery('#final_countdown_height').length)
					height=jQuery('#final_countdown_height').val();		
				
				if(event_name=="")
				{
					alert("Please enter event name");
					return;
				}

				var current_time=(new Date).getTime();
				var event_date_arr=event_date.split("/");
				var event_time_arr=event_time.split(":");
				var target_time=new Date(event_date_arr[2],(event_date_arr[1]-1),event_date_arr[0],event_time_arr[0],event_time_arr[1],0,0).getTime();
				
				jQuery('.final_countdown_spinner').css('visibility', 'visible');
				jQuery.post(
					    ajaxurl, 
					    {
					        'action': 'call_event_api',
					        'data':  {
								   "Eventid": "",
								   "startTime": 0,
								   "targetTime": target_time,
								   "createdDate": current_time,
								   "eventName": event_name,
								   "countUp":count_up,
								   "timezone": timezone,
								   "recurring": 0,
								   "skin": {
								     "id": "1000",
								     "color": title_color,
								     "bgColor": backgroound_color,
								     "titleColor": title_color,
								     "borderColor": -9539986,
								     "fontId": font_style
								   },
								   "shareType": "wordpress",
								   "lastUpdated": current_time,
								   "tags": [],
								   "_deleted": false
							   }
					    }, 
					    function(response){
					    	  jQuery('.final_countdown_spinner').css('visibility', 'hidden');
					   		   var response= JSON.parse(response);
						       if(response['status'])
						       {
						    	  	tagtext = '[final_countdown id="'+response['data']['eventId']+'" width="'+width+'" height="'+height+'"]';
					              	window.send_to_editor(tagtext);
					          		tb_remove();
						       }
						       else
						       {
							       alert(response['message']);
						       }
						     
					    }
					);
        }	
            </script>
	<?php 
	die;
	}
	
	/**
	 * Call event api.
	 *
	 * @since    1.0.0
	 */
	public function final_countdown_call_event_api() {
		
		$info = $_POST['data'];
		$message=array();
		$response = wp_remote_post(
				'https://origin.fncd.net/api/event',
				array(
						'method' => 'POST',
						'timeout' => 45,						
						'httpversion' => '1.0',						
						'headers' => array(
								'Content-Type' => 'application/json',								
						),
						'cookies' => array(),
						'body' => json_encode($info),
				)
		);
		
		if ( is_wp_error( $response ) ) {
			$error_message = $response->get_error_message();
			$message=array(
					'status'=>0,
					'message'=>"Something went wrong: $error_message",				
					'data'=>''
			);
		} else {
			
			if($response['response']['code']=="200")
			{
				$message=array(
						'status'=>1,
						'message'=>$response['response']['message'],
						'data'=>json_decode($response['body'],1)
				);
			}
			else
			{
				$message=array(
						'status'=>0,
						'message'=>$response['response']['message'],
						'data'=>''
				);
			}
		} 
		echo json_encode($message);
		die;
	}
}